pub struct Full<T>(pub T);Expand description
Error returned when a bounded allocator is full.
Contains the value that could not be allocated, allowing recovery.
Tuple Fields
0: TImplementations
Sourceimpl<T> Full<T>
impl<T> Full<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the error, returning the value that could not be allocated.